# CloudTips SDK for Android

CloudTips SDK позволяет интегрировать прием чаевых в мобильные приложение для платформы Android.

### Требования
Для работы CloudTips SDK необходим Android версии 6 (API level 23) или выше.

### Подключение
Для подключения SDK в build.gradle уровня проекта добавить репозитрий Jitpack:

```
allprojects {
		repositories {
			...
			maven { url 'https://jitpack.io' }
		}
	}
```

И в build.gradle уровня приложения добавить зависимость:

```
dependencies {
	implementation 'ru.cloudpayments.gitpub.integrations.sdk.cloudtips-android:sdk:2.3.0'
}
```

### Google Pay

CloudTips SDK поддерживает Google Pay.
Чтобы включить Google Pay в приложении, добавьте следующие метаданные в тег <application> файла AndroidManifest.xml.

```
<meta-data
    android:name="com.google.android.gms.wallet.api.enabled"
    android:value="true" />
```

### Yandex Pay

CloudTips SDK поддерживает Yandex Pay.
Чтобы включить Yandex Pay в приложении, добавьте в build.gradle:

```
defaultConfig { 
	...
	manifestPlaceholders = [YANDEX_CLIENT_ID: "ID взять из админки Яндекса https://oauth.yandex.ru/"]
	...
}
```

Ключи подписи и название пакета добавить в админку Яндекса в необходимые поля: SHA256 Fingerprints и Android package name

### Tinkoff Pay & SBP

CloudTips SDK поддерживает Tinkoff Pay и СБП. Для интеграции обязательно указать следующее в build.gradle:
```
defaultConfig { 
	...
	manifestPlaceholders = [CTSDK_CLIENT_ID: "<CLOUDTIPS_ID>"]
	...
}
```
, где CTSDK_CLIENT_ID - идентификатор для каждого клиента, можно узнать у поставщика или подставить рандомную строку, т.к. это нужно для работы возврата в
приложение после оплаты в Tinkoff.


### Структура проекта:

* **app** - Пример реализации приложения с использованием SDK
* **sdk** - Исходный код SDK

### Использование

Создайте инстанс объекта TipsManager

```
val tipsManager = TipsManager.getInstance(context)
```

Для запуска оплаты чаевых требуется передать объект Config, в котором задаются дополнительные параметры:

```
val config = Config.Builder(layoutId)
                    .setInvoiceId(invoiceId)
                    .setSum(sum)
                    .setAmount(amount)
                    .build()
tipsManager.launch(config)
, где layoutId - идентификатор визитки CloudTips
      invoiceId (optional) - идентифиактор invoice
      sum (optional) - сумма в чеке
      amount (optional) - чаевые по-умолчанию
```

### Поддержка

По возникающим вопросам техничечкого характера обращайтесь на support@cp.ru
