package ru.cloudtips.sdk

import android.content.Context
import android.content.Intent
import ru.cloudtips.sdk.helpers.AmplitudeManager
import ru.cloudtips.sdk.helpers.SbpHelper
import ru.cloudtips.sdk.helpers.SharedPrefs
import ru.cloudtips.sdk.network.NetworkClient
import ru.cloudtips.sdk.ui.activities.tips.PaymentTipsActivity


internal val networkClient: NetworkClient by lazy {
    TipsManager.mNetworkClient!!
}

val amplitude: AmplitudeManager by lazy {
    TipsManager.mAmplitude!!
}

val sharedPrefs: SharedPrefs by lazy {
    TipsManager.mSharedPrefs!!
}

class TipsManager(private val context: Context) {
    init {
        mNetworkClient = NetworkClient()
        mAmplitude = AmplitudeManager(context)
        SbpHelper.init()
        mSharedPrefs = SharedPrefs(context)
    }

    fun launch(config: Config) {
        val intent = PaymentTipsActivity.newIntent(context, config)
        intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_EXCLUDE_FROM_RECENTS
        context.startActivity(intent)
    }

    companion object {
        internal var mNetworkClient: NetworkClient? = null
        internal var mAmplitude: AmplitudeManager? = null
        internal var mSharedPrefs: SharedPrefs? = null

        fun getInstance(context: Context): TipsManager {
            return TipsManager(context)
        }
    }
}